#
# PySNMP MIB module GMPLS-TE-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/GMPLS-TE-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:14:16 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( IANAGmplsGeneralizedPidTC, IANAGmplsLSPEncodingTypeTC, IANAGmplsAdminStatusInformationTC, IANAGmplsSwitchingTypeTC, ) = mibBuilder.importSymbols("IANA-GMPLS-TC-MIB", "IANAGmplsGeneralizedPidTC", "IANAGmplsLSPEncodingTypeTC", "IANAGmplsAdminStatusInformationTC", "IANAGmplsSwitchingTypeTC")
( InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
( mplsStdMIB, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "mplsStdMIB")
( mplsTunnelScalarGroup, mplsTunnelCHopIndex, mplsTunnelInstance, mplsTunnelCHopListIndex, mplsTunnelEntry, mplsTunnelGroup, mplsTunnelIndex, mplsTunnelIngressLSRId, mplsTunnelARHopIndex, mplsTunnelEgressLSRId, mplsTunnelHopListIndex, mplsTunnelOperStatus, mplsTunnelHopIndex, mplsTunnelHopPathOptionIndex, mplsTunnelARHopListIndex, mplsTunnelAdminStatus, ) = mibBuilder.importSymbols("MPLS-TE-STD-MIB", "mplsTunnelScalarGroup", "mplsTunnelCHopIndex", "mplsTunnelInstance", "mplsTunnelCHopListIndex", "mplsTunnelEntry", "mplsTunnelGroup", "mplsTunnelIndex", "mplsTunnelIngressLSRId", "mplsTunnelARHopIndex", "mplsTunnelEgressLSRId", "mplsTunnelHopListIndex", "mplsTunnelOperStatus", "mplsTunnelHopIndex", "mplsTunnelHopPathOptionIndex", "mplsTunnelARHopListIndex", "mplsTunnelAdminStatus")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( ModuleIdentity, Bits, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, zeroDotZero, TimeTicks, Integer32, ObjectIdentity, iso, Unsigned32, Counter64, NotificationType, Counter32, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "Bits", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32", "zeroDotZero", "TimeTicks", "Integer32", "ObjectIdentity", "iso", "Unsigned32", "Counter64", "NotificationType", "Counter32", "IpAddress")
( RowPointer, TimeStamp, TruthValue, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowPointer", "TimeStamp", "TruthValue", "TextualConvention", "DisplayString")
gmplsTeStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 13)).setRevisions(("2007-02-27 00:00",))
if mibBuilder.loadTexts: gmplsTeStdMIB.setLastUpdated('200702270000Z')
if mibBuilder.loadTexts: gmplsTeStdMIB.setOrganization('IETF Common Control and Measurement Plane (CCAMP) Working\n         Group')
if mibBuilder.loadTexts: gmplsTeStdMIB.setContactInfo('       Thomas D. Nadeau\n                Cisco Systems, Inc.\n         Email: tnadeau@cisco.com\n                Adrian Farrel\n                Old Dog Consulting\n         Email: adrian@olddog.co.uk\n\n         Comments about this document should be emailed directly\n         to the CCAMP working group mailing list at\n         ccamp@ops.ietf.org.')
if mibBuilder.loadTexts: gmplsTeStdMIB.setDescription('Copyright (C) The IETF Trust (2007).  This version of\n         this MIB module is part of RFC 4802; see the RFC itself for\n         full legal notices.\n\n         This MIB module contains managed object definitions\n         for GMPLS Traffic Engineering (TE) as defined in:\n         1. Generalized Multi-Protocol Label Switching (GMPLS)\n            Signaling Functional Description, Berger, L. (Editor),\n            RFC 3471, January 2003.\n         2. Generalized MPLS Signaling - RSVP-TE Extensions, Berger,\n            L. (Editor), RFC 3473, January 2003.\n         ')
gmplsTeNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 13, 0))
gmplsTeScalars = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 13, 1))
gmplsTeObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 13, 2))
gmplsTeConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 13, 3))
gmplsTunnelsConfigured = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 13, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelsConfigured.setDescription('The number of GMPLS tunnels configured on this device.  A GMPLS\n     tunnel is considered configured if an entry for the tunnel\n     exists in the gmplsTunnelTable and the associated\n     mplsTunnelRowStatus is active(1).')
gmplsTunnelsActive = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 13, 1, 2), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelsActive.setDescription('The number of GMPLS tunnels active on this device.  A GMPLS\n     tunnel is considered active if there is an entry in the\n     gmplsTunnelTable and the associated mplsTunnelOperStatus for the\n     tunnel is up(1).')
gmplsTunnelTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1), )
if mibBuilder.loadTexts: gmplsTunnelTable.setDescription('The gmplsTunnelTable sparsely extends the mplsTunnelTable of\n     MPLS-TE-STD-MIB.  It allows GMPLS tunnels to be created between\n     an LSR and a remote endpoint, and existing tunnels to be\n     reconfigured or removed.\n\n     Note that only point-to-point tunnel segments are supported,\n     although multipoint-to-point and point-to-multipoint\n     connections are supported by an LSR acting as a cross-connect.\n     Each tunnel can thus have one out-segment originating at this\n     LSR and/or one in-segment terminating at this LSR.\n\n     The row status of an entry in this table is controlled by the\n     mplsTunnelRowStatus in the corresponding entry in the\n     mplsTunnelTable.  When the corresponding mplsTunnelRowStatus has\n     value active(1), a row in this table may not be created or\n     modified.\n\n     The exception to this rule is the\n     gmplsTunnelAdminStatusInformation object, which can be modified\n     while the tunnel is active.')
gmplsTunnelEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelInstance"), (0, "MPLS-TE-STD-MIB", "mplsTunnelIngressLSRId"), (0, "MPLS-TE-STD-MIB", "mplsTunnelEgressLSRId"))
if mibBuilder.loadTexts: gmplsTunnelEntry.setDescription('An entry in this table in association with the corresponding\n     entry in the mplsTunnelTable represents a GMPLS tunnel.\n\n     An entry can be created by a network administrator via SNMP SET\n     commands, or in response to signaling protocol events.')
gmplsTunnelUnnumIf = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 1), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelUnnumIf.setDescription("Denotes whether or not this tunnel corresponds to an unnumbered\n     interface represented by an entry in the interfaces group table\n     (the ifTable) with ifType set to mpls(166).\n     This object is only used if mplsTunnelIsIf is set to 'true'.\n\n     If both this object and the mplsTunnelIsIf object are set to\n     'true', the originating LSR adds an LSP_TUNNEL_INTERFACE_ID\n     object to the outgoing Path message.\n\n     This object contains information that is only used by the\n     terminating LSR.")
gmplsTunnelAttributes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 2), Bits().clone(namedValues=NamedValues(("labelRecordingDesired", 0),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelAttributes.setDescription('This bitmask indicates optional parameters for this tunnel.\n     These bits should be taken in addition to those defined in\n     mplsTunnelSessionAttributes in order to determine the full set\n     of options to be signaled (for example SESSION_ATTRIBUTES flags\n     in RSVP-TE).  The following describes these bitfields:\n\n     labelRecordingDesired\n       This flag is set to indicate that label information should be\n       included when doing a route record.  This bit is not valid\n       unless the recordRoute bit is set.')
gmplsTunnelLSPEncoding = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 3), IANAGmplsLSPEncodingTypeTC().clone('tunnelLspNotGmpls')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelLSPEncoding.setDescription("This object indicates the encoding of the LSP being requested.\n\n     A value of 'tunnelLspNotGmpls' indicates that GMPLS signaling is\n     not in use.  Some objects in this MIB module may be of use for\n     MPLS signaling extensions that do not use GMPLS signaling.  By\n     setting this object to 'tunnelLspNotGmpls', an application may\n     indicate that only those objects meaningful in MPLS should be\n     examined.\n\n     The values to use are defined in the TEXTUAL-CONVENTION\n     IANAGmplsLSPEncodingTypeTC found in the IANA-GMPLS-TC-MIB\n     module.")
gmplsTunnelSwitchingType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 4), IANAGmplsSwitchingTypeTC().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelSwitchingType.setDescription("Indicates the type of switching that should be performed on\n     a particular link.  This field is needed for links that\n     advertise more than one type of switching capability.\n\n     The values to use are defined in the TEXTUAL-CONVENTION\n     IANAGmplsSwitchingTypeTC found in the IANA-GMPLS-TC-MIB module.\n\n     This object is only meaningful if gmplsTunnelLSPEncodingType\n     is not set to 'tunnelLspNotGmpls'.")
gmplsTunnelLinkProtection = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 5), Bits().clone(namedValues=NamedValues(("extraTraffic", 0), ("unprotected", 1), ("shared", 2), ("dedicatedOneToOne", 3), ("dedicatedOnePlusOne", 4), ("enhanced", 5),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelLinkProtection.setDescription("This bitmask indicates the level of link protection required.  A\n     value of zero (no bits set) indicates that any protection may be\n     used.  The following describes these bitfields:\n\n     extraTraffic\n       This flag is set to indicate that the LSP should use links\n       that are protecting other (primary) traffic.  Such LSPs may be\n       preempted when the links carrying the (primary) traffic being\n       protected fail.\n\n     unprotected\n       This flag is set to indicate that the LSP should not use any\n       link layer protection.\n\n     shared\n       This flag is set to indicate that a shared link layer\n       protection scheme, such as 1:N protection, should be used to\n       support the LSP.\n\n     dedicatedOneToOne\n       This flag is set to indicate that a dedicated link layer\n       protection scheme, i.e., 1:1 protection, should be used to\n       support the LSP.\n\n     dedicatedOnePlusOne\n       This flag is set to indicate that a dedicated link layer\n       protection scheme, i.e., 1+1 protection, should be used to\n       support the LSP.\n\n     enhanced\n       This flag is set to indicate that a protection scheme that is\n       more reliable than Dedicated 1+1 should be used, e.g., 4 fiber\n       BLSR/MS-SPRING.\n\n     This object is only meaningful if gmplsTunnelLSPEncoding is\n     not set to 'tunnelLspNotGmpls'.")
gmplsTunnelGPid = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 6), IANAGmplsGeneralizedPidTC().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelGPid.setDescription("This object indicates the payload carried by the LSP.  It is only\n     required when GMPLS will be used for this LSP.\n\n     The values to use are defined in the TEXTUAL-CONVENTION\n     IANAGmplsGeneralizedPidTC found in the IANA-GMPLS-TC-MIB module.\n\n     This object is only meaningful if gmplsTunnelLSPEncoding is not\n     set to 'tunnelLspNotGmpls'.")
gmplsTunnelSecondary = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 7), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelSecondary.setDescription("Indicates that the requested LSP is a secondary LSP.\n\n     This object is only meaningful if gmplsTunnelLSPEncoding is not\n     set to 'tunnelLspNotGmpls'.")
gmplsTunnelDirection = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1,))).clone(namedValues=NamedValues(("forward", 0), ("bidirectional", 1),)).clone('forward')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelDirection.setDescription("Whether this tunnel carries forward data only (is\n     unidirectional) or is bidirectional.\n\n     Values of this object other than 'forward' are meaningful\n     only if gmplsTunnelLSPEncoding is not set to\n     'tunnelLspNotGmpls'.")
gmplsTunnelPathComp = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 9), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("dynamicFull", 1), ("explicit", 2), ("dynamicPartial", 3),)).clone('dynamicFull')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelPathComp.setDescription("This value instructs the source node on how to perform path\n     computation on the explicit route specified by the associated\n     entries in the gmplsTunnelHopTable.\n\n     dynamicFull\n       The user specifies at least the source and\n       destination of the path and expects that the Constrained\n       Shortest Path First (CSPF) will calculate the remainder\n       of the path.\n\n     explicit\n       The user specifies the entire path for the tunnel to\n       take.  This path may contain strict or loose hops.\n       Evaluation of the explicit route will be performed\n       hop by hop through the network.\n\n     dynamicPartial\n       The user specifies at least the source and\n       destination of the path and expects that the CSPF\n       will calculate the remainder of the path.  The path\n       computed by CSPF is allowed to be only partially\n       computed allowing the remainder of the path to be\n       filled in across the network.\n\n     When an entry is present in the gmplsTunnelTable for a\n     tunnel, gmplsTunnelPathComp MUST be used and any\n     corresponding mplsTunnelHopEntryPathComp object in the\n     mplsTunnelHopTable MUST be ignored and SHOULD not be set.\n\n     mplsTunnelHopTable and mplsTunnelHopEntryPathComp are part of\n     MPLS-TE-STD-MIB.\n\n     This object should be ignored if the value of\n     gmplsTunnelLSPEncoding is 'tunnelLspNotGmpls'.")
gmplsTunnelUpstreamNotifyRecipientType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 10), InetAddressType().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelUpstreamNotifyRecipientType.setDescription('This object is used to aid in interpretation of\n    gmplsTunnelUpstreamNotifyRecipient.')
gmplsTunnelUpstreamNotifyRecipient = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 11), InetAddress().clone(hexValue="00000000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelUpstreamNotifyRecipient.setDescription('Indicates the address of the upstream recipient for Notify\n     messages relating to this tunnel and issued by this LSR.  This\n     information is typically received from an upstream LSR in a Path\n     message.\n\n     This object is only valid when signaling a tunnel using RSVP.\n\n     It is also not valid at the head end of a tunnel since there are\n     no upstream LSRs to which to send a Notify message.\n\n     This object is interpreted in the context of the value of\n     gmplsTunnelUpstreamNotifyRecipientType. If this object is set to\n     0, the value of gmplsTunnelUpstreamNotifyRecipientType MUST be\n     set to unknown(0).')
gmplsTunnelSendResvNotifyRecipientType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 12), InetAddressType().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelSendResvNotifyRecipientType.setDescription('This object is used to aid in interpretation of\n    gmplsTunnelSendResvNotifyRecipient.')
gmplsTunnelSendResvNotifyRecipient = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 13), InetAddress().clone(hexValue="00000000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelSendResvNotifyRecipient.setDescription('Indicates to an upstream LSR the address to which it should send\n     downstream Notify messages relating to this tunnel.\n\n     This object is only valid when signaling a tunnel using RSVP.\n\n     It is also not valid at the head end of the tunnel since no Resv\n     messages are sent from that LSR for this tunnel.\n\n     If set to 0, no Notify Request object will be included in the\n     outgoing Resv messages.\n\n     This object is interpreted in the context of the value of\n     gmplsTunnelSendResvNotifyRecipientType. If this object is set to\n     0, the value of gmplsTunnelSendResvNotifyRecipientType MUST be\n     set to unknown(0).')
gmplsTunnelDownstreamNotifyRecipientType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 14), InetAddressType().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelDownstreamNotifyRecipientType.setDescription('This object is used to aid in interpretation of\n    gmplsTunnelDownstreamNotifyRecipient.')
gmplsTunnelDownstreamNotifyRecipient = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 15), InetAddress().clone(hexValue="00000000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelDownstreamNotifyRecipient.setDescription('Indicates the address of the downstream recipient for Notify\n     messages relating to this tunnel and issued by this LSR.  This\n     information is typically received from an upstream LSR in a Resv\n     message.  This object is only valid when signaling a tunnel using\n     RSVP.\n\n     It is also not valid at the tail end of a tunnel since there are\n     no downstream LSRs to which to send a Notify message.\n\n     This object is interpreted in the context of the value of\n     gmplsTunnelDownstreamNotifyRecipientType. If this object is set\n     to 0, the value of gmplsTunnelDownstreamNotifyRecipientType MUST\n     be set to unknown(0).')
gmplsTunnelSendPathNotifyRecipientType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 16), InetAddressType().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelSendPathNotifyRecipientType.setDescription('This object is used to aid in interpretation of\n    gmplsTunnelSendPathNotifyRecipient.')
gmplsTunnelSendPathNotifyRecipient = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 17), InetAddress().clone(hexValue="00000000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelSendPathNotifyRecipient.setDescription('Indicates to a downstream LSR the address to which it should\n     send upstream Notify messages relating to this tunnel.\n\n     This object is only valid when signaling a tunnel using RSVP.\n\n     It is also not valid at the tail end of the tunnel since no Path\n     messages are sent from that LSR for this tunnel.\n\n     If set to 0, no Notify Request object will be included in the\n     outgoing Path messages.\n\n     This object is interpreted in the context of the value of\n     gmplsTunnelSendPathNotifyRecipientType.  If this object is set to\n     0, the value of gmplsTunnelSendPathNotifyRecipientType MUST be\n     set to unknown(0).')
gmplsTunnelAdminStatusFlags = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 18), IANAGmplsAdminStatusInformationTC()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelAdminStatusFlags.setDescription('Determines the setting of the Admin Status flags in the\n      Admin Status object or TLV, as described in RFC 3471.  Setting\n      this field to a non-zero value will result in the inclusion of\n      the Admin Status object on signaling messages.\n\n      The values to use are defined in the TEXTUAL-CONVENTION\n      IANAGmplsAdminStatusInformationTC found in the\n      IANA-GMPLS-TC-MIB module.\n\n      This value of this object can be modified when the\n      corresponding mplsTunnelRowStatus and mplsTunnelAdminStatus\n      is active(1).  By doing so, a new signaling message will be\n      triggered including the requested Admin Status object or\n      TLV.')
gmplsTunnelExtraParamsPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 1, 1, 19), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelExtraParamsPtr.setDescription('Some tunnels will run over transports that can usefully support\n     technology-specific additional parameters (for example,\n     Synchronous Optical Network (SONET) resource usage).  Such\n     parameters can be supplied in an external table and referenced\n     from here.\n\n     A value of zeroDotzero in this attribute indicates that there\n     is no such additional information.')
gmplsTunnelHopTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 2), )
if mibBuilder.loadTexts: gmplsTunnelHopTable.setDescription('The gmplsTunnelHopTable sparsely extends the mplsTunnelHopTable\n     of MPLS-TE-STD-MIB.  It is used to indicate the Explicit Labels\n     to be used in an explicit path for a GMPLS tunnel defined in the\n     mplsTunnelTable and gmplsTunnelTable, when it is established\n     using signaling.  It does not insert new hops, but does define\n     new values for hops defined in the mplsTunnelHopTable.\n\n     Each row in this table is indexed by the same indexes as in the\n     mplsTunnelHopTable.  It is acceptable for some rows in the\n     mplsTunnelHopTable to have corresponding entries in this table\n     and some to have no corresponding entry in this table.\n\n     The storage type for this entry is given by the value\n     of mplsTunnelHopStorageType in the corresponding entry in the\n     mplsTunnelHopTable.\n\n     The row status of an entry in this table is controlled by\n     mplsTunnelHopRowStatus in the corresponding entry in the\n     mplsTunnelHopTable.  That is, it is not permitted to create a row\n     in this table, or to modify an existing row, when the\n     corresponding mplsTunnelHopRowStatus has the value active(1).')
gmplsTunnelHopEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 2, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelHopListIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelHopPathOptionIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelHopIndex"))
if mibBuilder.loadTexts: gmplsTunnelHopEntry.setDescription('An entry in this table represents additions to a tunnel hop\n     defined in mplsTunnelHopEntry.  At an ingress to a tunnel, an\n     entry in this table is created by a network administrator for an\n     ERLSP to be set up by a signaling protocol.  At transit and\n     egress nodes, an entry in this table may be used to represent the\n     explicit path instructions received using the signaling\n     protocol.')
gmplsTunnelHopLabelStatuses = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 2, 1, 1), Bits().clone(namedValues=NamedValues(("forwardPresent", 0), ("reversePresent", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelHopLabelStatuses.setDescription('This bitmask indicates the presence of labels indicated by the\n     gmplsTunnelHopExplicitForwardLabel or\n     gmplsTunnelHopExplicitForwardLabelPtr, and\n     gmplsTunnelHopExplicitReverseLabel or\n     gmplsTunnelHopExplicitReverseLabelPtr objects.\n\n     For the Present bits, a set bit indicates that a label is\n     present for this hop in the route.  This allows zero to be a\n     valid label value.')
gmplsTunnelHopExplicitForwardLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 2, 1, 2), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelHopExplicitForwardLabel.setDescription('If gmplsTunnelHopLabelStatuses object indicates that a Forward\n     Label is present and gmplsTunnelHopExplicitForwardLabelPtr\n     contains the value zeroDotZero, then the label to use on this\n     hop is represented by the value of this object.')
gmplsTunnelHopExplicitForwardLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 2, 1, 3), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelHopExplicitForwardLabelPtr.setDescription('If the gmplsTunnelHopLabelStatuses object indicates that a\n     Forward Label is present, this object contains a pointer to a\n     row in another MIB table (such as the gmplsLabelTable of\n     GMPLS-LABEL-STD-MIB) that contains the label to use on this hop\n     in the forward direction.\n\n     If the gmplsTunnelHopLabelStatuses object indicates that a\n     Forward Label is present and this object contains the value\n     zeroDotZero, then the label to use on this hop is found in the\n     gmplsTunnelHopExplicitForwardLabel object.')
gmplsTunnelHopExplicitReverseLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 2, 1, 4), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelHopExplicitReverseLabel.setDescription('If the gmplsTunnelHopLabelStatuses object indicates that a\n     Reverse Label is present and\n     gmplsTunnelHopExplicitReverseLabelPtr contains the value\n     zeroDotZero, then the label to use on this hop is found in\n     this object encoded as a 32-bit integer.')
gmplsTunnelHopExplicitReverseLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 2, 1, 5), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsTunnelHopExplicitReverseLabelPtr.setDescription('If the gmplsTunnelHopLabelStatuses object indicates that a\n     Reverse Label is present, this object contains a pointer to a\n     row in another MIB table (such as the gmplsLabelTable of\n     GMPLS-LABEL-STD-MIB) that contains the label to use on this hop\n     in the reverse direction.\n\n     If the gmplsTunnelHopLabelStatuses object indicates that a\n     Reverse Label is present and this object contains the value\n     zeroDotZero, then the label to use on this hop is found in the\n     gmplsTunnelHopExplicitReverseLabel object.')
gmplsTunnelARHopTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 3), )
if mibBuilder.loadTexts: gmplsTunnelARHopTable.setDescription('The gmplsTunnelARHopTable sparsely extends the\n     mplsTunnelARHopTable of MPLS-TE-STD-MIB.  It is used to\n     indicate the labels currently in use for a GMPLS tunnel\n     defined in the mplsTunnelTable and gmplsTunnelTable, as\n     reported by the signaling protocol.  It does not insert\n     new hops, but does define new values for hops defined in\n     the mplsTunnelARHopTable.\n\n     Each row in this table is indexed by the same indexes as in the\n     mplsTunnelARHopTable.  It is acceptable for some rows in the\n     mplsTunnelARHopTable to have corresponding entries in this table\n     and some to have no corresponding entry in this table.\n\n     Note that since the information necessary to build entries\n     within this table is not provided by some signaling protocols\n     and might not be returned in all cases of other signaling\n     protocols, implementation of this table and the\n     mplsTunnelARHopTable is optional.  Furthermore, since the\n     information in this table is actually provided by the\n     signaling protocol after the path has been set up, the entries\n     in this table are provided only for observation, and hence,\n     all variables in this table are accessible exclusively as\n     read-only.')
gmplsTunnelARHopEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 3, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelARHopListIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelARHopIndex"))
if mibBuilder.loadTexts: gmplsTunnelARHopEntry.setDescription('An entry in this table represents additions to a tunnel hop\n     visible in mplsTunnelARHopEntry.  An entry is created by the\n     signaling protocol for a signaled ERLSP set up by the signaling\n     protocol.\n\n     At any node on the LSP (ingress, transit, or egress), this table\n     and the mplsTunnelARHopTable (if the tables are supported and if\n     the signaling protocol is recording actual route information)\n     contain the actual route of the whole tunnel.  If the signaling\n     protocol is not recording the actual route, this table MAY\n     report the information from the gmplsTunnelHopTable or the\n     gmplsTunnelCHopTable.\n\n     Note that the recording of actual labels is distinct from the\n     recording of the actual route in some signaling protocols.  This\n     feature is enabled using the gmplsTunnelAttributes object.')
gmplsTunnelARHopLabelStatuses = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 3, 1, 1), Bits().clone(namedValues=NamedValues(("forwardPresent", 0), ("reversePresent", 1), ("forwardGlobal", 2), ("reverseGlobal", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelARHopLabelStatuses.setDescription('This bitmask indicates the presence and status of labels\n     indicated by the gmplsTunnelARHopExplicitForwardLabel or\n     gmplsTunnelARHopExplicitForwardLabelPtr, and\n     gmplsTunnelARHopExplicitReverseLabel or\n     gmplsTunnelARHopExplicitReverseLabelPtr objects.\n\n     For the Present bits, a set bit indicates that a label is\n     present for this hop in the route.\n\n     For the Global bits, a set bit indicates that the label comes\n     from the Global Label Space; a clear bit indicates that this is\n     a Per-Interface label.  A Global bit only has meaning if the\n     corresponding Present bit is set.')
gmplsTunnelARHopExplicitForwardLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 3, 1, 2), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelARHopExplicitForwardLabel.setDescription('If the gmplsTunnelARHopLabelStatuses object indicates that a\n     Forward Label is present and\n     gmplsTunnelARHopExplicitForwardLabelPtr contains the value\n     zeroDotZero, then the label in use on this hop is found in this\n     object encoded as a 32-bit integer.')
gmplsTunnelARHopExplicitForwardLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 3, 1, 3), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelARHopExplicitForwardLabelPtr.setDescription('If the gmplsTunnelARHopLabelStatuses object indicates that a\n     Forward Label is present, this object contains a pointer to a\n     row in another MIB table (such as the gmplsLabelTable of\n     GMPLS-LABEL-STD-MIB) that contains the label in use on this hop\n     in the forward direction.\n\n     If the gmplsTunnelARHopLabelStatuses object indicates that a\n     Forward Label is present and this object contains the value\n     zeroDotZero, then the label in use on this hop is found in the\n     gmplsTunnelARHopExplicitForwardLabel object.')
gmplsTunnelARHopExplicitReverseLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 3, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelARHopExplicitReverseLabel.setDescription('If the gmplsTunnelARHopLabelStatuses object indicates that a\n     Reverse Label is present and\n     gmplsTunnelARHopExplicitReverseLabelPtr contains the value\n     zeroDotZero, then the label in use on this hop is found in this\n     object encoded as a 32-bit integer.')
gmplsTunnelARHopExplicitReverseLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 3, 1, 5), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelARHopExplicitReverseLabelPtr.setDescription('If the gmplsTunnelARHopLabelStatuses object indicates that a\n     Reverse Label is present, this object contains a pointer to a\n     row in another MIB table (such as the gmplsLabelTable of\n     GMPLS-LABEL-STD-MIB) that contains the label in use on this hop\n     in the reverse direction.\n\n     If the gmplsTunnelARHopLabelStatuses object indicates that a\n     Reverse Label is present and this object contains the value\n     zeroDotZero, then the label in use on this hop is found in the\n     gmplsTunnelARHopExplicitReverseLabel object.')
gmplsTunnelARHopProtection = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 3, 1, 6), Bits().clone(namedValues=NamedValues(("localAvailable", 0), ("localInUse", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelARHopProtection.setDescription('Availability and usage of protection on the reported link.\n\n     localAvailable\n       This flag is set to indicate that the link downstream of this\n       node is protected via a local repair mechanism.\n\n     localInUse\n       This flag is set to indicate that a local repair mechanism is\n       in use to maintain this tunnel (usually in the face of an\n       outage of the link it was previously routed over).')
gmplsTunnelCHopTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 4), )
if mibBuilder.loadTexts: gmplsTunnelCHopTable.setDescription('The gmplsTunnelCHopTable sparsely extends the\n     mplsTunnelCHopTable of MPLS-TE-STD-MIB.  It is used to indicate\n     additional information about the hops of a GMPLS tunnel defined\n     in the mplsTunnelTable and gmplsTunnelTable, as computed by a\n     constraint-based routing protocol, based on the\n     mplsTunnelHopTable and the gmplsTunnelHopTable.\n\n     Each row in this table is indexed by the same indexes as in the\n     mplsTunnelCHopTable.  It is acceptable for some rows in the\n     mplsTunnelCHopTable to have corresponding entries in this table\n     and some to have no corresponding entry in this table.\n\n     Please note that since the information necessary to build\n     entries within this table may not be supported by some LSRs,\n     implementation of this table is optional.\n\n     Furthermore, since the information in this table is actually\n     provided by a path computation component after the path has been\n     computed, the entries in this table are provided only for\n     observation, and hence, all objects in this table are accessible\n     exclusively as read-only.')
gmplsTunnelCHopEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 4, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelCHopListIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelCHopIndex"))
if mibBuilder.loadTexts: gmplsTunnelCHopEntry.setDescription('An entry in this table represents additions to a computed tunnel\n     hop visible in mplsTunnelCHopEntry.  An entry is created by a\n     path computation component based on the hops specified in the\n     corresponding mplsTunnelHopTable and gmplsTunnelHopTable.\n\n     At a transit LSR, this table (if the table is supported) MAY\n     contain the path computed by a path computation engine on (or on\n     behalf of) the transit LSR.')
gmplsTunnelCHopLabelStatuses = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 4, 1, 1), Bits().clone(namedValues=NamedValues(("forwardPresent", 0), ("reversePresent", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelCHopLabelStatuses.setDescription('This bitmask indicates the presence of labels indicated by the\n     gmplsTunnelCHopExplicitForwardLabel or\n     gmplsTunnelCHopExplicitForwardLabelPtr and\n     gmplsTunnelCHopExplicitReverseLabel or\n     gmplsTunnelCHopExplicitReverseLabelPtr objects.\n\n     A set bit indicates that a label is present for this hop in the\n     route, thus allowing zero to be a valid label value.')
gmplsTunnelCHopExplicitForwardLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 4, 1, 2), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelCHopExplicitForwardLabel.setDescription('If the gmplsTunnelCHopLabelStatuses object indicates that a\n     Forward Label is present and\n     gmplsTunnelCHopExplicitForwardLabelPtr contains the value\n     zeroDotZero, then the label to use on this hop is found in this\n     object encoded as a 32-bit integer.')
gmplsTunnelCHopExplicitForwardLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 4, 1, 3), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelCHopExplicitForwardLabelPtr.setDescription('If the gmplsTunnelCHopLabelStatuses object indicates that a\n     Forward Label is present, this object contains a pointer to a\n     row in another MIB table (such as the gmplsLabelTable of\n     GMPLS-LABEL-STD-MIB) that contains the label to use on this hop\n     in the forward direction.\n\n     If the gmplsTunnelCHopLabelStatuses object indicates that a\n     Forward Label is present and this object contains the value\n     zeroDotZero, then the label to use on this hop is found in the\n     gmplsTunnelCHopExplicitForwardLabel object.')
gmplsTunnelCHopExplicitReverseLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 4, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelCHopExplicitReverseLabel.setDescription('If the gmplsTunnelCHopLabelStatuses object indicates that a\n     Reverse Label is present and\n     gmplsTunnelCHopExplicitReverseLabelPtr contains the value\n     zeroDotZero, then the label to use on this hop is found in this\n     object encoded as a 32-bit integer.')
gmplsTunnelCHopExplicitReverseLabelPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 4, 1, 5), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelCHopExplicitReverseLabelPtr.setDescription('If the gmplsTunnelCHopLabelStatuses object indicates that a\n     Reverse Label is present, this object contains a pointer to a\n     row in another MIB table (such as the gmplsLabelTable of\n     GMPLS-LABEL-STD-MIB) that contains the label to use on this hop\n     in the reverse direction.\n\n     If the gmplsTunnelCHopLabelStatuses object indicates that a\n     Reverse Label is present and this object contains the value\n     zeroDotZero, then the label to use on this hop is found in the\n     gmplsTunnelCHopExplicitReverseLabel object.')
gmplsTunnelReversePerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 5), )
if mibBuilder.loadTexts: gmplsTunnelReversePerfTable.setDescription('This table augments the gmplsTunnelTable to provide\n     per-tunnel packet performance information for the reverse\n     direction of a bidirectional tunnel.  It can be seen as\n     supplementing the mplsTunnelPerfTable, which augments the\n     mplsTunnelTable.\n\n     For links that do not transport packets, these packet counters\n     cannot be maintained.  For such links, attempts to read the\n     objects in this table will return noSuchInstance.\n\n     A tunnel can be known to be bidirectional by inspecting the\n     gmplsTunnelDirection object.')
gmplsTunnelReversePerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 5, 1), )
gmplsTunnelEntry.registerAugmentions(("GMPLS-TE-STD-MIB", "gmplsTunnelReversePerfEntry"))
gmplsTunnelReversePerfEntry.setIndexNames(*gmplsTunnelEntry.getIndexNames())
if mibBuilder.loadTexts: gmplsTunnelReversePerfEntry.setDescription('An entry in this table is created by the LSR for every\n     bidirectional GMPLS tunnel where packets are visible to the\n     LSR.')
gmplsTunnelReversePerfPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 5, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelReversePerfPackets.setDescription('Number of packets forwarded on the tunnel in the reverse\n     direction if it is bidirectional.\n\n     This object represents the 32-bit value of the least\n     significant part of the 64-bit value if both\n     gmplsTunnelReversePerfHCPackets and this object are returned.\n     For links that do not transport packets, this packet counter\n     cannot be maintained.  For such links, this value will return\n     noSuchInstance.')
gmplsTunnelReversePerfHCPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 5, 1, 2), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelReversePerfHCPackets.setDescription('High-capacity counter for number of packets forwarded on the\n     tunnel in the reverse direction if it is bidirectional.\n\n     For links that do not transport packets, this packet counter\n     cannot be maintained.  For such links, this value will return\n     noSuchInstance.')
gmplsTunnelReversePerfErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 5, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelReversePerfErrors.setDescription('Number of errored packets received on the tunnel in the reverse\n     direction if it is bidirectional.  For links that do not\n     transport packets, this packet counter cannot be maintained.  For\n     such links, this value will return noSuchInstance.')
gmplsTunnelReversePerfBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 5, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelReversePerfBytes.setDescription('Number of bytes forwarded on the tunnel in the reverse direction\n     if it is bidirectional.\n\n     This object represents the 32-bit value of the least\n     significant part of the 64-bit value if both\n     gmplsTunnelReversePerfHCBytes and this object are returned.\n\n     For links that do not transport packets, this packet counter\n     cannot be maintained.  For such links, this value will return\n     noSuchInstance.')
gmplsTunnelReversePerfHCBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 5, 1, 5), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelReversePerfHCBytes.setDescription('High-capacity counter for number of bytes forwarded on the\n     tunnel in the reverse direction if it is bidirectional.\n\n     For links that do not transport packets, this packet counter\n     cannot be maintained.  For such links, this value will return\n     noSuchInstance.')
gmplsTunnelErrorTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6), )
if mibBuilder.loadTexts: gmplsTunnelErrorTable.setDescription('This table augments the mplsTunnelTable.\n\n     This table provides per-tunnel information about errors.  Errors\n     may be detected locally or reported through the signaling\n     protocol.  Error reporting is not exclusive to GMPLS, and this\n     table may be applied in MPLS systems.\n\n     Entries in this table are not persistent over system resets\n     or re-initializations of the management system.')
gmplsTunnelErrorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1), )
mplsTunnelEntry.registerAugmentions(("GMPLS-TE-STD-MIB", "gmplsTunnelErrorEntry"))
gmplsTunnelErrorEntry.setIndexNames(*mplsTunnelEntry.getIndexNames())
if mibBuilder.loadTexts: gmplsTunnelErrorEntry.setDescription('An entry in this table is created by the LSR for every tunnel\n     where error information is visible to the LSR.\n\n     Note that systems that read the objects in this table one at\n     a time and do not perform atomic operations to read entire\n     instantiated table rows at once, should, for each conceptual\n     column with valid data, read gmplsTunnelErrorLastTime\n     prior to the other objects in the row and again subsequent to\n     reading the last object of the row.  They should verify that\n     the value of gmplsTunnelErrorLastTime did not change and\n     thereby ensure that all data read belongs to the same error\n     event.')
gmplsTunnelErrorLastErrorType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("noError", 0), ("unknown", 1), ("protocol", 2), ("pathComputation", 3), ("localConfiguration", 4), ("localResources", 5), ("localOther", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelErrorLastErrorType.setDescription('The nature of the last error.  Provides interpretation context\n     for gmplsTunnelErrorProtocolCode and\n     gmplsTunnelErrorProtocolSubcode.\n\n     A value of noError(0) shows that there is no error associated\n     with this tunnel and means that the other objects in this table\n     entry (conceptual row) have no meaning.\n\n     A value of unknown(1) shows that there is an error but that no\n     additional information about the cause is known.  The error may\n     have been received in a signaled message or generated locally.\n\n     A value of protocol(2) or pathComputation(3) indicates the\n     cause of an error and identifies an error that has been received\n     through signaling or will itself be signaled.\n\n     A value of localConfiguration(4), localResources(5) or\n     localOther(6) identifies an error that has been detected\n     by the local node but that will not be reported through\n     signaling.')
gmplsTunnelErrorLastTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1, 2), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelErrorLastTime.setDescription('The time at which the last error occurred.  This is presented as\n     the value of SysUpTime when the error occurred or was reported\n     to this node.\n\n     If gmplsTunnelErrorLastErrorType has the value noError(0), then\n     this object is not valid and should be ignored.\n\n     Note that entries in this table are not persistent over system\n     resets or re-initializations of the management system.')
gmplsTunnelErrorReporterType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1, 3), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelErrorReporterType.setDescription('The address type of the error reported.\n\n      This object is used to aid in interpretation of\n      gmplsTunnelErrorReporter.')
gmplsTunnelErrorReporter = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1, 4), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelErrorReporter.setDescription('The address of the node reporting the last error, or the address\n     of the resource (such as an interface) associated with the\n     error.\n\n     If gmplsTunnelErrorLastErrorType has the value noError(0), then\n     this object is not valid and should be ignored.\n\n     If gmplsTunnelErrorLastErrorType has the value unknown(1),\n     localConfiguration(4), localResources(5), or localOther(6),\n     this object MAY contain a zero value.\n\n     This object should be interpreted in the context of the value of\n     the object gmplsTunnelErrorReporterType.')
gmplsTunnelErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1, 5), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelErrorCode.setDescription('The primary error code associated with the last error.\n\n     The interpretation of this error code depends on the value of\n     gmplsTunnelErrorLastErrorType.  If the value of\n     gmplsTunnelErrorLastErrorType is noError(0), the value of this\n     object should be 0 and should be ignored.  If the value of\n     gmplsTunnelErrorLastErrorType is protocol(2), the error should\n     be interpreted in the context of the signaling protocol\n     identified by the mplsTunnelSignallingProto object.')
gmplsTunnelErrorSubcode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1, 6), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelErrorSubcode.setDescription('The secondary error code associated with the last error and the\n     protocol used to signal this tunnel.  This value is interpreted\n     in the context of the value of gmplsTunnelErrorCode.\n     If the value of gmplsTunnelErrorLastErrorType is noError(0), the\n     value of this object should be 0 and should be ignored.')
gmplsTunnelErrorTLVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelErrorTLVs.setDescription('The sequence of interface identifier TLVs reported with the\n     error by the protocol code.  The interpretation of the TLVs and\n     the encoding within the protocol are described in the\n     references.  A value of zero in the first octet indicates that no\n     TLVs are present.')
gmplsTunnelErrorHelpString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 13, 2, 6, 1, 8), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: gmplsTunnelErrorHelpString.setDescription('A textual string containing information about the last error,\n     recovery actions, and support advice.  If there is no help string,\n     this object contains a zero length string.\n     If the value of gmplsTunnelErrorLastErrorType is noError(0),\n     this object should contain a zero length string, but may contain\n     a help string indicating that there is no error.')
gmplsTunnelDown = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 13, 0, 1)).setObjects(*(("GMPLS-TE-STD-MIB", "mplsTunnelAdminStatus"), ("GMPLS-TE-STD-MIB", "mplsTunnelOperStatus"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorLastErrorType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorReporterType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorReporter"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorCode"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorSubcode"),))
if mibBuilder.loadTexts: gmplsTunnelDown.setDescription('This notification is generated when an mplsTunnelOperStatus\n      object for a tunnel in the gmplsTunnelTable is about to enter\n      the down state from some other state (but not from the\n      notPresent state).  This other state is indicated by the\n      included value of mplsTunnelOperStatus.\n\n      The objects in this notification provide additional error\n      information that indicates the reason why the tunnel has\n      transitioned to down(2).\n\n      Note that an implementation MUST only issue one of\n      mplsTunnelDown and gmplsTunnelDown for any single event on a\n      single tunnel.  If the tunnel has an entry in the\n      gmplsTunnelTable, an implementation SHOULD use gmplsTunnelDown\n      for all tunnel-down events and SHOULD NOT use mplsTunnelDown.\n\n      This notification is subject to the control of\n      mplsTunnelNotificationEnable.  When that object is set\n      to false(2), then the notification must not be issued.\n\n      Further, this notification is also subject to\n      mplsTunnelNotificationMaxRate.  That object indicates the\n      maximum number of notifications issued per second.  If events\n      occur more rapidly, the implementation may simply fail to emit\n      some notifications during that period, or may queue them until\n      an appropriate time.  The notification rate applies to the sum\n      of all notifications in the MPLS-TE-STD-MIB and\n      GMPLS-TE-STD-MIB modules applied across the whole of the\n      reporting device.\n\n      mplsTunnelOperStatus, mplsTunnelAdminStatus, mplsTunnelDown,\n      mplsTunnelNotificationEnable, and mplsTunnelNotificationMaxRate\n      objects are found in MPLS-TE-STD-MIB.')
gmplsTeGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 1))
gmplsTeCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 2))
gmplsTeModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 2, 1)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelScalarGroup"), ("GMPLS-TE-STD-MIB", "gmplsTunnelGroup"), ("GMPLS-TE-STD-MIB", "gmplsTunnelScalarGroup"), ("GMPLS-TE-STD-MIB", "gmplsTunnelSignaledGroup"), ("GMPLS-TE-STD-MIB", "gmplsTunnelOptionalGroup"), ("GMPLS-TE-STD-MIB", "gmplsTeNotificationGroup"),))
if mibBuilder.loadTexts: gmplsTeModuleFullCompliance.setDescription('Compliance statement for agents that provide full support for\n      GMPLS-TE-STD-MIB.  Such devices can then be monitored and also\n      be configured using this MIB module.\n\n      The mandatory group has to be implemented by all LSRs that\n      originate, terminate, or act as transit for TE-LSPs/tunnels.\n      In addition, depending on the type of tunnels supported, other\n      groups become mandatory as explained below.')
gmplsTeModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 2, 2)).setObjects(*(("GMPLS-TE-STD-MIB", "gmplsTunnelGroup"), ("GMPLS-TE-STD-MIB", "gmplsTunnelScalarGroup"), ("GMPLS-TE-STD-MIB", "gmplsTunnelSignaledGroup"), ("GMPLS-TE-STD-MIB", "gmplsTunnelOptionalGroup"), ("GMPLS-TE-STD-MIB", "gmplsTeNotificationGroup"),))
if mibBuilder.loadTexts: gmplsTeModuleReadOnlyCompliance.setDescription('Compliance requirement for implementations that only provide\n     read-only support for GMPLS-TE-STD-MIB.  Such devices can then be\n     monitored but cannot be configured using this MIB module.')
gmplsTunnelGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 1, 1)).setObjects(*(("GMPLS-TE-STD-MIB", "gmplsTunnelDirection"), ("GMPLS-TE-STD-MIB", "gmplsTunnelReversePerfPackets"), ("GMPLS-TE-STD-MIB", "gmplsTunnelReversePerfHCPackets"), ("GMPLS-TE-STD-MIB", "gmplsTunnelReversePerfErrors"), ("GMPLS-TE-STD-MIB", "gmplsTunnelReversePerfBytes"), ("GMPLS-TE-STD-MIB", "gmplsTunnelReversePerfHCBytes"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorLastErrorType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorLastTime"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorReporterType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorReporter"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorCode"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorSubcode"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorTLVs"), ("GMPLS-TE-STD-MIB", "gmplsTunnelErrorHelpString"), ("GMPLS-TE-STD-MIB", "gmplsTunnelUnnumIf"),))
if mibBuilder.loadTexts: gmplsTunnelGroup.setDescription('Necessary, but not sufficient, set of objects to implement\n     tunnels.  In addition, depending on the type of the tunnels\n     supported (for example, manually configured or signaled,\n     persistent or non-persistent, etc.), the\n     gmplsTunnelSignaledGroup group is mandatory.')
gmplsTunnelSignaledGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 1, 2)).setObjects(*(("GMPLS-TE-STD-MIB", "gmplsTunnelAttributes"), ("GMPLS-TE-STD-MIB", "gmplsTunnelLSPEncoding"), ("GMPLS-TE-STD-MIB", "gmplsTunnelSwitchingType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelLinkProtection"), ("GMPLS-TE-STD-MIB", "gmplsTunnelGPid"), ("GMPLS-TE-STD-MIB", "gmplsTunnelSecondary"), ("GMPLS-TE-STD-MIB", "gmplsTunnelPathComp"), ("GMPLS-TE-STD-MIB", "gmplsTunnelUpstreamNotifyRecipientType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelUpstreamNotifyRecipient"), ("GMPLS-TE-STD-MIB", "gmplsTunnelSendResvNotifyRecipientType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelSendResvNotifyRecipient"), ("GMPLS-TE-STD-MIB", "gmplsTunnelDownstreamNotifyRecipientType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelDownstreamNotifyRecipient"), ("GMPLS-TE-STD-MIB", "gmplsTunnelSendPathNotifyRecipientType"), ("GMPLS-TE-STD-MIB", "gmplsTunnelSendPathNotifyRecipient"), ("GMPLS-TE-STD-MIB", "gmplsTunnelAdminStatusFlags"), ("GMPLS-TE-STD-MIB", "gmplsTunnelHopLabelStatuses"), ("GMPLS-TE-STD-MIB", "gmplsTunnelHopExplicitForwardLabel"), ("GMPLS-TE-STD-MIB", "gmplsTunnelHopExplicitForwardLabelPtr"), ("GMPLS-TE-STD-MIB", "gmplsTunnelHopExplicitReverseLabel"), ("GMPLS-TE-STD-MIB", "gmplsTunnelHopExplicitReverseLabelPtr"),))
if mibBuilder.loadTexts: gmplsTunnelSignaledGroup.setDescription('Objects needed to implement signaled tunnels.')
gmplsTunnelScalarGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 1, 3)).setObjects(*(("GMPLS-TE-STD-MIB", "gmplsTunnelsConfigured"), ("GMPLS-TE-STD-MIB", "gmplsTunnelsActive"),))
if mibBuilder.loadTexts: gmplsTunnelScalarGroup.setDescription('Scalar objects needed to implement MPLS tunnels.')
gmplsTunnelOptionalGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 1, 4)).setObjects(*(("GMPLS-TE-STD-MIB", "gmplsTunnelExtraParamsPtr"), ("GMPLS-TE-STD-MIB", "gmplsTunnelARHopLabelStatuses"), ("GMPLS-TE-STD-MIB", "gmplsTunnelARHopExplicitForwardLabel"), ("GMPLS-TE-STD-MIB", "gmplsTunnelARHopExplicitForwardLabelPtr"), ("GMPLS-TE-STD-MIB", "gmplsTunnelARHopExplicitReverseLabel"), ("GMPLS-TE-STD-MIB", "gmplsTunnelARHopExplicitReverseLabelPtr"), ("GMPLS-TE-STD-MIB", "gmplsTunnelARHopProtection"), ("GMPLS-TE-STD-MIB", "gmplsTunnelCHopLabelStatuses"), ("GMPLS-TE-STD-MIB", "gmplsTunnelCHopExplicitForwardLabel"), ("GMPLS-TE-STD-MIB", "gmplsTunnelCHopExplicitForwardLabelPtr"), ("GMPLS-TE-STD-MIB", "gmplsTunnelCHopExplicitReverseLabel"), ("GMPLS-TE-STD-MIB", "gmplsTunnelCHopExplicitReverseLabelPtr"),))
if mibBuilder.loadTexts: gmplsTunnelOptionalGroup.setDescription('The objects in this group are optional.')
gmplsTeNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 166, 13, 3, 1, 5)).setObjects(*(("GMPLS-TE-STD-MIB", "gmplsTunnelDown"),))
if mibBuilder.loadTexts: gmplsTeNotificationGroup.setDescription('Set of notifications implemented in this module.  None is\n     mandatory.')
mibBuilder.exportSymbols("GMPLS-TE-STD-MIB", gmplsTunnelARHopTable=gmplsTunnelARHopTable, gmplsTunnelCHopLabelStatuses=gmplsTunnelCHopLabelStatuses, gmplsTunnelReversePerfTable=gmplsTunnelReversePerfTable, gmplsTunnelExtraParamsPtr=gmplsTunnelExtraParamsPtr, gmplsTunnelDirection=gmplsTunnelDirection, gmplsTunnelOptionalGroup=gmplsTunnelOptionalGroup, gmplsTunnelTable=gmplsTunnelTable, gmplsTunnelErrorSubcode=gmplsTunnelErrorSubcode, gmplsTunnelAttributes=gmplsTunnelAttributes, gmplsTunnelErrorCode=gmplsTunnelErrorCode, gmplsTunnelAdminStatusFlags=gmplsTunnelAdminStatusFlags, gmplsTeNotifications=gmplsTeNotifications, gmplsTunnelReversePerfErrors=gmplsTunnelReversePerfErrors, gmplsTunnelSwitchingType=gmplsTunnelSwitchingType, gmplsTunnelGPid=gmplsTunnelGPid, gmplsTunnelSendResvNotifyRecipient=gmplsTunnelSendResvNotifyRecipient, gmplsTunnelErrorHelpString=gmplsTunnelErrorHelpString, gmplsTunnelsConfigured=gmplsTunnelsConfigured, gmplsTeNotificationGroup=gmplsTeNotificationGroup, gmplsTunnelDownstreamNotifyRecipientType=gmplsTunnelDownstreamNotifyRecipientType, gmplsTunnelARHopExplicitReverseLabel=gmplsTunnelARHopExplicitReverseLabel, gmplsTunnelLinkProtection=gmplsTunnelLinkProtection, gmplsTunnelErrorTable=gmplsTunnelErrorTable, gmplsTeScalars=gmplsTeScalars, gmplsTunnelEntry=gmplsTunnelEntry, gmplsTunnelHopTable=gmplsTunnelHopTable, gmplsTunnelARHopExplicitForwardLabel=gmplsTunnelARHopExplicitForwardLabel, gmplsTunnelCHopExplicitForwardLabelPtr=gmplsTunnelCHopExplicitForwardLabelPtr, gmplsTunnelReversePerfHCBytes=gmplsTunnelReversePerfHCBytes, gmplsTunnelUpstreamNotifyRecipientType=gmplsTunnelUpstreamNotifyRecipientType, gmplsTeGroups=gmplsTeGroups, gmplsTeObjects=gmplsTeObjects, gmplsTunnelDownstreamNotifyRecipient=gmplsTunnelDownstreamNotifyRecipient, gmplsTunnelCHopEntry=gmplsTunnelCHopEntry, gmplsTunnelErrorLastErrorType=gmplsTunnelErrorLastErrorType, gmplsTunnelGroup=gmplsTunnelGroup, gmplsTunnelErrorEntry=gmplsTunnelErrorEntry, gmplsTunnelErrorTLVs=gmplsTunnelErrorTLVs, gmplsTunnelsActive=gmplsTunnelsActive, gmplsTunnelSendPathNotifyRecipientType=gmplsTunnelSendPathNotifyRecipientType, gmplsTunnelErrorLastTime=gmplsTunnelErrorLastTime, gmplsTunnelUpstreamNotifyRecipient=gmplsTunnelUpstreamNotifyRecipient, gmplsTunnelARHopLabelStatuses=gmplsTunnelARHopLabelStatuses, gmplsTunnelHopLabelStatuses=gmplsTunnelHopLabelStatuses, gmplsTeStdMIB=gmplsTeStdMIB, gmplsTunnelSignaledGroup=gmplsTunnelSignaledGroup, gmplsTunnelErrorReporter=gmplsTunnelErrorReporter, gmplsTunnelHopEntry=gmplsTunnelHopEntry, gmplsTunnelPathComp=gmplsTunnelPathComp, gmplsTunnelHopExplicitReverseLabel=gmplsTunnelHopExplicitReverseLabel, gmplsTunnelHopExplicitReverseLabelPtr=gmplsTunnelHopExplicitReverseLabelPtr, gmplsTunnelARHopEntry=gmplsTunnelARHopEntry, gmplsTunnelCHopExplicitForwardLabel=gmplsTunnelCHopExplicitForwardLabel, gmplsTunnelReversePerfEntry=gmplsTunnelReversePerfEntry, gmplsTunnelUnnumIf=gmplsTunnelUnnumIf, gmplsTunnelARHopExplicitForwardLabelPtr=gmplsTunnelARHopExplicitForwardLabelPtr, gmplsTunnelSendPathNotifyRecipient=gmplsTunnelSendPathNotifyRecipient, gmplsTeModuleReadOnlyCompliance=gmplsTeModuleReadOnlyCompliance, gmplsTeConformance=gmplsTeConformance, gmplsTunnelCHopTable=gmplsTunnelCHopTable, gmplsTeModuleFullCompliance=gmplsTeModuleFullCompliance, gmplsTunnelSecondary=gmplsTunnelSecondary, gmplsTunnelSendResvNotifyRecipientType=gmplsTunnelSendResvNotifyRecipientType, gmplsTunnelHopExplicitForwardLabel=gmplsTunnelHopExplicitForwardLabel, gmplsTunnelReversePerfBytes=gmplsTunnelReversePerfBytes, gmplsTunnelLSPEncoding=gmplsTunnelLSPEncoding, gmplsTunnelDown=gmplsTunnelDown, gmplsTeCompliances=gmplsTeCompliances, gmplsTunnelErrorReporterType=gmplsTunnelErrorReporterType, gmplsTunnelScalarGroup=gmplsTunnelScalarGroup, PYSNMP_MODULE_ID=gmplsTeStdMIB, gmplsTunnelHopExplicitForwardLabelPtr=gmplsTunnelHopExplicitForwardLabelPtr, gmplsTunnelARHopProtection=gmplsTunnelARHopProtection, gmplsTunnelReversePerfHCPackets=gmplsTunnelReversePerfHCPackets, gmplsTunnelCHopExplicitReverseLabelPtr=gmplsTunnelCHopExplicitReverseLabelPtr, gmplsTunnelARHopExplicitReverseLabelPtr=gmplsTunnelARHopExplicitReverseLabelPtr, gmplsTunnelReversePerfPackets=gmplsTunnelReversePerfPackets, gmplsTunnelCHopExplicitReverseLabel=gmplsTunnelCHopExplicitReverseLabel)



#
# PySNMP MIB module IANA-LANGUAGE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IANA-LANGUAGE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:15:55 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ValueRangeConstraint, ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ValueRangeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( Integer32, mib_2, Counter64, IpAddress, TimeTicks, Counter32, Unsigned32, Bits, MibIdentifier, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, ModuleIdentity, ObjectIdentity, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "mib-2", "Counter64", "IpAddress", "TimeTicks", "Counter32", "Unsigned32", "Bits", "MibIdentifier", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32", "ModuleIdentity", "ObjectIdentity", "NotificationType")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
ianaLanguages = ModuleIdentity((1, 3, 6, 1, 2, 1, 73)).setRevisions(("2000-05-10 00:00", "1999-09-09 09:00",))
if mibBuilder.loadTexts: ianaLanguages.setLastUpdated('200005100000Z')
if mibBuilder.loadTexts: ianaLanguages.setOrganization('IANA')
if mibBuilder.loadTexts: ianaLanguages.setContactInfo('Internet Assigned Numbers Authority (IANA)\n\n            Postal: ICANN\n                    4676 Admiralty Way, Suite 330\n                    Marina del Rey, CA 90292\n\n            Tel:    +1 310 823 9358 x20\n            E-Mail: iana&iana.org')
if mibBuilder.loadTexts: ianaLanguages.setDescription("The MIB module registers object identifier values for\n            well-known programming and scripting languages. Every\n            language registration MUST describe the format used\n            when transferring scripts written in this language.\n\n            Any additions or changes to the contents of this MIB\n            module require Designated Expert Review as defined in\n            the Guidelines for Writing IANA Considerations Section\n            document. The Designated Expert will be selected by\n            the IESG Area Director of the OPS Area.\n\n            Note, this module does not have to register all possible\n            languages since languages are identified by object\n            identifier values. It is therefore possible to registered \n            languages in private OID trees. The references given below are not\n            normative with regard to the language version. Other\n            references might be better suited to describe some newer \n            versions of this language. The references are only\n            provided as `a pointer into the right direction'.")
ianaLangJavaByteCode = ObjectIdentity((1, 3, 6, 1, 2, 1, 73, 1))
if mibBuilder.loadTexts: ianaLangJavaByteCode.setDescription('Java byte code to be processed by a Java virtual machine.\n            A script written in Java byte code is transferred by using\n            the Java archive file format (JAR).')
ianaLangTcl = ObjectIdentity((1, 3, 6, 1, 2, 1, 73, 2))
if mibBuilder.loadTexts: ianaLangTcl.setDescription('The Tool Command Language (Tcl). A script written in the\n            Tcl language is transferred in Tcl source code format.')
ianaLangPerl = ObjectIdentity((1, 3, 6, 1, 2, 1, 73, 3))
if mibBuilder.loadTexts: ianaLangPerl.setDescription('The Perl language. A script written in the Perl language\n            is transferred in Perl source code format.')
ianaLangScheme = ObjectIdentity((1, 3, 6, 1, 2, 1, 73, 4))
if mibBuilder.loadTexts: ianaLangScheme.setDescription('The Scheme language. A script written in the Scheme\n            language is transferred in Scheme source code format.')
ianaLangSRSL = ObjectIdentity((1, 3, 6, 1, 2, 1, 73, 5))
if mibBuilder.loadTexts: ianaLangSRSL.setDescription('The SNMP Script Language defined by SNMP Research. A\n            script written in the SNMP Script Language is transferred\n            in the SNMP Script Language source code format.')
ianaLangPSL = ObjectIdentity((1, 3, 6, 1, 2, 1, 73, 6))
if mibBuilder.loadTexts: ianaLangPSL.setDescription('The Patrol Script Language defined by BMC Software. A script\n            written in the Patrol Script Language is transferred in the\n            Patrol Script Language source code format.')
ianaLangSMSL = ObjectIdentity((1, 3, 6, 1, 2, 1, 73, 7))
if mibBuilder.loadTexts: ianaLangSMSL.setDescription('The Systems Management Scripting Language. A script written\n            in the SMSL language is transferred in the SMSL source code\n            format.')
mibBuilder.exportSymbols("IANA-LANGUAGE-MIB", ianaLangScheme=ianaLangScheme, ianaLangJavaByteCode=ianaLangJavaByteCode, ianaLangPerl=ianaLangPerl, ianaLanguages=ianaLanguages, ianaLangTcl=ianaLangTcl, PYSNMP_MODULE_ID=ianaLanguages, ianaLangPSL=ianaLangPSL, ianaLangSMSL=ianaLangSMSL, ianaLangSRSL=ianaLangSRSL)



#
# PySNMP MIB module T11-FC-FSPF-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-FSPF-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:30:06 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( fcmSwitchIndex, fcmInstanceIndex, FcDomainIdOrZero, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "fcmSwitchIndex", "fcmInstanceIndex", "FcDomainIdOrZero")
( InterfaceIndex, ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "ifIndex")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( ObjectIdentity, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, Gauge32, iso, Counter64, MibIdentifier, ModuleIdentity, Unsigned32, IpAddress, Counter32, Integer32, TimeTicks, mib_2, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ObjectIdentity", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "Gauge32", "iso", "Counter64", "MibIdentifier", "ModuleIdentity", "Unsigned32", "IpAddress", "Counter32", "Integer32", "TimeTicks", "mib-2")
( RowStatus, TruthValue, DisplayString, TextualConvention, StorageType, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TruthValue", "DisplayString", "TextualConvention", "StorageType")
( t11FamConfigDomainId, ) = mibBuilder.importSymbols("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamConfigDomainId")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11FcFspfMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 143)).setRevisions(("2006-08-14 00:00",))
if mibBuilder.loadTexts: t11FcFspfMIB.setLastUpdated('200608140000Z')
if mibBuilder.loadTexts: t11FcFspfMIB.setOrganization('T11')
if mibBuilder.loadTexts: t11FcFspfMIB.setContactInfo('Claudio DeSanti\n                    Cisco Systems, Inc.\n                    170 West Tasman Drive\n                    San Jose, CA 95134 USA\n                    EMail: cds@cisco.com\n\n\n\n\n                    Keith McCloghrie\n                    Cisco Systems, Inc.\n                    170 West Tasman Drive\n                    San Jose, CA USA 95134\n                    Email: kzm@cisco.com')
if mibBuilder.loadTexts: t11FcFspfMIB.setDescription('The MIB module for managing the Fabric Shortest Path\n           First (FSPF) protocol.  FSPF is specified in FC-SW-4.\n\n           Copyright (C) The Internet Society (2006).  This version of\n           this MIB module is part of RFC 4626;  see the RFC itself for\n           full legal notices.')
t11FspfNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 0))
t11FspfObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 1))
t11FspfConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 2))
t11FspfConfiguration = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 1, 1))
t11FspfDatabase = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 1, 2))
class T11FspfLsrType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,255)

class T11FspfLinkType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,255)

class T11FspfInterfaceState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))
    namedValues = NamedValues(("down", 1), ("init", 2), ("dbExchange", 3), ("dbAckwait", 4), ("dbWait", 5), ("full", 6),)

class T11FspfLastCreationTime(TimeTicks, TextualConvention):
    pass

t11FspfTable = MibTable((1, 3, 6, 1, 2, 1, 143, 1, 1, 1), )
if mibBuilder.loadTexts: t11FspfTable.setDescription("This table allows the users to configure and monitor FSPF's\n           per-Fabric parameters and statistics on all Fabrics known to\n           locally managed switches.\n\n           Entries are created/removed by the agent if and when\n           (Virtual) Fabrics are created/deleted.")
t11FspfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfFabricIndex"))
if mibBuilder.loadTexts: t11FspfEntry.setDescription("An entry containing FSPF variables, parameters, and\n           statistics on a particular switch (identified by values\n           of fcmInstanceIndex and fcmSwitchIndex) for a particular\n           Fabric (identified by a t11FspfFabricIndex value).\n\n           (Note that the local switch's per-fabric Domain-ID is\n           available in t11FamConfigDomainId, which is defined in\n           T11-FC-FABRIC-ADDR-MGR-MIB.)")
t11FspfFabricIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 1), T11FabricIndex())
if mibBuilder.loadTexts: t11FspfFabricIndex.setDescription('A unique index value that uniquely identifies a\n           particular Fabric.\n\n           In a Fabric conformant to FC-SW-4, multiple Virtual Fabrics\n           can operate within one (or more) physical infrastructures.\n           In such a case, index value is used to uniquely identify a\n           particular Fabric within a physical infrastructure.\n\n           In a Fabric that has (can have) only a single Fabric\n           operating within the physical infrastructure, the\n           value of this Fabric Index will always be 1.')
t11FspfMinLsArrival = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(1000)).setUnits('milliSeconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfMinLsArrival.setDescription('The minimum time after accepting a Link State Record\n           (LSR) on this Fabric before accepting another update of\n           the same LSR on the same Fabric.\n\n           An LSR update that is not accepted because of this time\n           interval is discarded.')
t11FspfMinLsInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(5000)).setUnits('milliSeconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfMinLsInterval.setDescription('The minimum time after this switch sends an LSR on this\n           Fabric before it will send another update of the same LSR\n           on the same Fabric.')
t11FspfLsRefreshTime = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 4), Unsigned32().clone(30)).setUnits('Minutes').setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsRefreshTime.setDescription('The interval between transmission of refresh LSRs on this\n           Fabric.')
t11FspfMaxAge = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 5), Unsigned32().clone(60)).setUnits('Minutes').setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfMaxAge.setDescription('The maximum age an LSR will be retained in the FSPF\n           database on this Fabric.  An LSR is removed from the\n           database after MaxAge is reached.')
t11FspfMaxAgeDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfMaxAgeDiscards.setDescription('The number of LSRs discarded due to their age reaching\n           t11FspfMaxAge in this Fabric.  The last discontinuity of\n           this counter is indicated by t11FspfCreateTime.')
t11FspfPathComputations = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfPathComputations.setDescription('The number of times that the path computation algorithm\n           has been invoked by this Switch on this Fabric to compute\n           a set of minimum cost paths for this Fabric.  The last\n\n\n\n           discontinuity of this counter is indicated by\n           t11FspfCreateTime.')
t11FspfChecksumErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfChecksumErrors.setDescription('The number of FSPF checksum errors that were detected\n           locally (and therefore discarded) on this Fabric.\n           The last discontinuity of this counter is indicated by\n           t11FspfCreateTime.')
t11FspfLsrs = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 9), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrs.setDescription('The current number of entries for this Fabric in the\n           t11FspfLsrTable.')
t11FspfCreateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 10), T11FspfLastCreationTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfCreateTime.setDescription('The value of sysUpTime when this entry was last created.')
t11FspfAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 11), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),)).clone('up')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfAdminStatus.setDescription("The desired state of FSPF in this Fabric.  If value of\n           this object is set to 'up', then FSPF is enabled in\n           this Fabric.  If set to 'down', then FSPF is disabled\n           in this Fabric -- when FSPF is disabled, FSPF provides\n\n\n\n           no routes to be included in the T11-FC-ROUTE-MIB module.\n           (see the T11-FC-ROUTE-MIB).")
t11FspfOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfOperStatus.setDescription("State of FSPF in this Fabric.  If 't11FspfAdminStatus' is\n           'down', then the 't11FspfOperStatus' should be 'down'.\n           If 't11FspfAdminStatus' is changed to 'up', then\n           't11FspfOperStatus' should change to 'up' as and when\n           FSPF is active in this Fabric.")
t11FspfNbrStateChangNotifyEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 13), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfNbrStateChangNotifyEnable.setDescription("Specifies whether or not the local agent should\n           issue the notification 't11FspfNbrStateChangNotify'\n           when the local switch learns of a change of state\n           in the FSPF Neighbor Finite State Machine on an\n           interface in this Fabric.\n           If the value of the object is 'true, then the\n           notification is generated.  If the value is 'false',\n           notification is not generated.")
t11FspfSetToDefault = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("default", 1), ("noOp", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfSetToDefault.setDescription("Setting this value to 'default' changes the value of each\n           and every writable object in this row to its default\n\n\n\n           value.\n\n           No action is taken if this object is set to 'noOp'.\n           The value of the object, when read, is always 'noOp'.")
t11FspfStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 1, 1, 15), StorageType().clone('nonVolatile')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FspfStorageType.setDescription("The storage type for read-write objects in this\n           conceptual row.\n\n           Conceptual rows having the value 'permanent' need not\n           allow write-access to any columnar objects in the row.")
t11FspfIfTable = MibTable((1, 3, 6, 1, 2, 1, 143, 1, 1, 2), )
if mibBuilder.loadTexts: t11FspfIfTable.setDescription("This table allows the users to configure and monitor\n           the FSPF parameters that are per-interface (identified\n           by a t11FspfIfIndex value), per-Fabric (identified by a\n           t11FspfFabricIndex value), and per-switch (identified by\n           values of fcmInstanceIndex and fcmSwitchIndex).\n\n           Creating a row in this table via t11FspfIfRowStatus\n           provides the means to specify non-default parameter value(s)\n           for an interface at a time when the relevant row in this\n           table would not otherwise exist because the interface is\n           either down or it is not an E_Port, but the corresponding\n           row in the t11FspfTable must already exist.\n\n           After the non-default values have been specified for a\n           port's parameters, they need to be retained in this table,\n           even when the port becomes 'isolated'.  However, having\n           unnecessary rows in this table clutters it up and makes\n           those rows that are useful harder for an NMS to find.\n           Therefore, when an E_Port becomes isolated, its row gets\n           deleted if and only if all of its parameter values are the\n           default values; also, when an E_Port becomes non-isolated\n\n\n\n           in a particular Fabric, a row in this table needs to exist\n           and is automatically created, if necessary.\n\n           The specific conditions for an automated/implicit deletion\n           of a row are:\n           a) if the corresponding interface is no longer an E_Port\n              (e.g., a G_Port which is dynamically determined to be an\n              F_Port), and all configurable parameters have default\n              values; or\n           b) if the interface identified by t11FspfIfIndex no longer\n              exists (e.g., because a line-card is physically removed);\n              or\n           c) if the corresponding row in the t11FspfTable is deleted.\n           ")
t11FspfIfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfFabricIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfIfIndex"))
if mibBuilder.loadTexts: t11FspfIfEntry.setDescription('An entry containing FSPF information for the interface\n           identified by t11FspfIfIndex, on the fabric identified\n           by t11FspfFabricIndex, on the switch identified by\n           fcmSwitchIndex.')
t11FspfIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: t11FspfIfIndex.setDescription('The value of ifIndex that identifies the local\n           Fibre Channel interface for which this entry\n           contains FSPF information.')
t11FspfIfHelloInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(20)).setUnits('Seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfHelloInterval.setDescription('Interval between the periodic HELLO messages sent on this\n           interface in this Fabric to verify the link health.  Note\n           that this value must be same at both ends of a link in\n           this Fabric.')
t11FspfIfDeadInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(2,65535)).clone(80)).setUnits('Seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfDeadInterval.setDescription('Maximum time for which no HELLO messages can be received\n           on this interface in this Fabric.  After this time, the\n           interface is assumed to be broken and removed from the\n           database.  Note that this value must be greater than the\n           HELLO interval specified on this interface in this Fabric.')
t11FspfIfRetransmitInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(5)).setUnits('Seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfRetransmitInterval.setDescription('The time after which an unacknowledged LSR is\n           retransmitted on this interface in this Fabric.')
t11FspfIfInLsuPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfInLsuPkts.setDescription('Number of Link State Update (LSU) packets received on\n           this interface in this Fabric.  The last discontinuity\n           of this counter is indicated by t11FspfIfCreateTime.')
t11FspfIfInLsaPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfInLsaPkts.setDescription('Number of Link State Acknowledgement (LSA) packets\n           received on this interface in this Fabric.  The last\n           discontinuity of this counter is indicated by\n           t11FspfIfCreateTime.')
t11FspfIfOutLsuPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfOutLsuPkts.setDescription('Number of Link State Update (LSU) packets transmitted\n           on this interface in this Fabric.  The last\n           discontinuity of this counter is indicated by\n           t11FspfIfCreateTime.')
t11FspfIfOutLsaPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfOutLsaPkts.setDescription('Number of Link State Acknowledgement (LSA) packets\n           transmitted on this interface in this Fabric.  The\n           last discontinuity of this counter is indicated by\n           t11FspfIfCreateTime.')
t11FspfIfOutHelloPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfOutHelloPkts.setDescription('Number of HELLO packets transmitted on this interface in\n           this Fabric.  The last discontinuity of this counter is\n           indicated by t11FspfIfCreateTime.')
t11FspfIfInHelloPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfInHelloPkts.setDescription('Number of HELLO packets received on this interface in\n           this Fabric.  The last discontinuity of this counter is\n           indicated by t11FspfIfCreateTime.')
t11FspfIfRetransmittedLsuPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfRetransmittedLsuPkts.setDescription('The number of LSU packets that contained one or more\n           retransmitted LSRs, and that were transmitted on this\n           interface in this Fabric.  The last discontinuity of\n           this counter is indicated by t11FspfIfCreateTime.')
t11FspfIfInErrorPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfInErrorPkts.setDescription('Number of invalid FSPF control packets received on this\n           interface in this Fabric.  The last discontinuity of\n           this counter is indicated by t11FspfIfCreateTime.')
t11FspfIfNbrState = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 13), T11FspfInterfaceState()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfNbrState.setDescription("The state of FSPF's 'neighbor state machine', which is\n           the operational state of the interaction with the\n\n\n\n           neighbor's interface that is connected to this interface.\n\n           If the 't11FspfIfAdminStatus' is 'down', then this object\n           should be 'down'.  If the 't11FspfIfAdminStatus' is 'up',\n           then this object's value depends on the state of FSPF's\n           'neighbor state machine' on this interface in this\n           Fabric.")
t11FspfIfNbrDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 14), FcDomainIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfNbrDomainId.setDescription('The Domain Id of the neighbor in this Fabric.')
t11FspfIfNbrPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 15), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,16777215))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfNbrPortIndex.setDescription("The index, as known by the neighbor, of the neighbor's\n           interface that is connected to this interface in this\n           Fabric.")
t11FspfIfAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),)).clone('up')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfAdminStatus.setDescription("The desired state of FSPF on this interface in this\n           Fabric, whenever 't11FspfAdminStatus' is 'up'.\n           If the value of this object is set to 'up', then FSPF is\n           enabled on this interface in this Fabric.  If set to\n           'down', then FSPF is disabled on this interface in this\n           Fabric.  Note that the operational state of FSPF on an\n           interface is given by t11FspfIfNbrState.")
t11FspfIfCreateTime = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 17), T11FspfLastCreationTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfIfCreateTime.setDescription('The value of sysUpTime when this entry was last\n           created.')
t11FspfIfSetToDefault = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 18), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("default", 1), ("noOp", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfSetToDefault.setDescription("Setting this value to 'default' changes the value of each\n           and every writable object in this row to its default\n           value.\n\n           If all the configuration parameters have their default\n           values, and if the interface is down, then the row is\n           deleted automatically.\n\n           No action is taken if this object is set to 'noOp'.\n           The value of the object, when read, is always 'noOp'.")
t11FspfIfLinkCostFactor = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 19), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(100)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfLinkCostFactor.setDescription('The administrative factor used in calculating the cost\n           of sending a frame on this interface in this Fabric.\n\n           The formula used to calculate the link cost is:\n\n                    Link Cost = S * (1.0625e12 / ifSpeed)\n           where:\n             S = (the value of this object / 100)\n             ifSpeed = interface speed (as defined in the IF-MIB).\n           ')
t11FspfIfStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 20), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfStorageType.setDescription("The storage type for this conceptual row.\n            Conceptual rows having the value 'permanent' need not\n            allow write-access to any columnar objects in the row.")
t11FspfIfRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 1, 2, 1, 21), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FspfIfRowStatus.setDescription("The status of the conceptual row.\n\n           This object can be used to create an entry only if there\n           is an entry in the t11FspfTable for the corresponding\n           Fabric, and if the interface is either isolated or is a\n           non-E_port.\n\n           Setting this object to 'destroy' will typically fail;\n           to reverse the creation process, set the corresponding\n           instance of t11FspfIfSetToDefault to 'default'.")
t11FspfLsrTable = MibTable((1, 3, 6, 1, 2, 1, 143, 1, 2, 1), )
if mibBuilder.loadTexts: t11FspfLsrTable.setDescription("This table is the database of all the latest\n           incarnations of the Link State Records (LSRs) that\n           are currently contained in the topology database,\n           for all interfaces on all Fabrics known to\n           locally managed switches.\n\n           A Fabric's topology database contains the LSRs that\n           have been either issued or received by a local switch on\n           that Fabric, and that have not reached t11FspfMaxAge.")
t11FspfLsrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfFabricIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfLsrDomainId"), (0, "T11-FC-FSPF-MIB", "t11FspfLsrType"))
if mibBuilder.loadTexts: t11FspfLsrEntry.setDescription('This gives information for the most recent update of an\n           LSR.  There is one entry for every LSR issued or received\n           by a locally managed switch (identified by\n           fcmInstanceIndex and fcmSwitchIndex) in a Fabric\n           (identified by t11FspfFabricIndex).')
t11FspfLsrDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 1), FcDomainIdOrZero())
if mibBuilder.loadTexts: t11FspfLsrDomainId.setDescription('Domain Id of the LSR owner in this Fabric.  It is the\n           Link State Id of this LSR.')
t11FspfLsrType = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 2), T11FspfLsrType())
if mibBuilder.loadTexts: t11FspfLsrType.setDescription('Type of this LSR.')
t11FspfLsrAdvDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 3), FcDomainIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrAdvDomainId.setDescription('Domain Id of the switch that is advertising the LSR on\n           the behalf of the switch owning it.')
t11FspfLsrAge = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setUnits('Seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrAge.setDescription('The time since this LSR was inserted into the database.')
t11FspfLsrIncarnationNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrIncarnationNumber.setDescription('The link state incarnation number of this LSR.  This is\n           used to identify most recent instance of an LSR while\n           updating the topology database when an LSR is received.\n           The updating of an LSR includes incrementing its\n           incarnation number prior to transmission of the updated\n           LSR.  So, the most recent LSR is the one with the\n           largest incarnation number.')
t11FspfLsrCheckSum = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 6), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrCheckSum.setDescription('The checksum of the LSR.')
t11FspfLsrLinks = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 1, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65355))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLsrLinks.setDescription('Number of entries in the t11FspfLinkTable associated with\n           this LSR.')
t11FspfLinkNumber = MibScalar((1, 3, 6, 1, 2, 1, 143, 1, 2, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkNumber.setDescription('The number of rows in the t11FspfLinkTable.')
t11FspfLinkTable = MibTable((1, 3, 6, 1, 2, 1, 143, 1, 2, 4), )
if mibBuilder.loadTexts: t11FspfLinkTable.setDescription('This table contains the list of Inter-Switch Links and\n           their information that is part of an LSR, either\n           received or transmitted.')
t11FspfLinkEntry = MibTableRow((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfFabricIndex"), (0, "T11-FC-FSPF-MIB", "t11FspfLsrDomainId"), (0, "T11-FC-FSPF-MIB", "t11FspfLsrType"), (0, "T11-FC-FSPF-MIB", "t11FspfLinkIndex"))
if mibBuilder.loadTexts: t11FspfLinkEntry.setDescription('An entry that contains information about a link\n           contained in an LSR in this Fabric.  An entry is created\n           whenever a new link appears in an (issued or received)\n           LSR.  An entry is deleted when a link no longer appears\n           in an (issued or received) LSR.')
t11FspfLinkIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11FspfLinkIndex.setDescription('An arbitrary index of this link.')
t11FspfLinkNbrDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 2), FcDomainIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkNbrDomainId.setDescription('The Domain Id of the neighbor on the other end of this\n           link in this Fabric.')
t11FspfLinkPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,16777215))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkPortIndex.setDescription("The source E_port of this link, as indicated by the index\n           value in the LSR received from the switch identified by\n           't11FspfLsrDomainId'.")
t11FspfLinkNbrPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,16777215))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkNbrPortIndex.setDescription("The destination E_port of this link, as indicated by the\n           index value in the LSR received from the switch identified\n           by 't11FspfLinkNbrDomainId'.")
t11FspfLinkType = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 5), T11FspfLinkType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkType.setDescription('The type of this link.')
t11FspfLinkCost = MibTableColumn((1, 3, 6, 1, 2, 1, 143, 1, 2, 4, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FspfLinkCost.setDescription('The cost of sending a frame on this link in this Fabric.\n           Link cost is calculated using the formula:\n\n                 link cost = S * (1.0625e12 / Signalling Rate)\n\n           For issued LSRs, S is determined by the value of\n           t11FspfIfLinkCostFactor for the corresponding interface\n\n\n\n           and Fabric.')
t11FspfIfPrevNbrState = MibScalar((1, 3, 6, 1, 2, 1, 143, 1, 1, 3), T11FspfInterfaceState()).setMaxAccess("accessiblefornotify")
if mibBuilder.loadTexts: t11FspfIfPrevNbrState.setDescription("The previous state of FSPF's Neighbor Finite State\n           Machine on an interface.\n\n           This object is only used in the\n           't11FspfNbrStateChangNotify' notification.")
t11FspfNbrStateChangNotify = NotificationType((1, 3, 6, 1, 2, 1, 143, 0, 1)).setObjects(*(("T11-FC-FSPF-MIB", "ifIndex"), ("T11-FC-FSPF-MIB", "t11FamConfigDomainId"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrDomainId"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrState"), ("T11-FC-FSPF-MIB", "t11FspfIfPrevNbrState"),))
if mibBuilder.loadTexts: t11FspfNbrStateChangNotify.setDescription("This notification signifies that there has been a change in\n           the state of an FSPF neighbor.  This is generated when the\n           FSPF state changes to a terminal state, through either\n           regression (i.e., goes from Full to Init or Down) or\n           progression (i.e., from any state to Full).  The value of\n           't11FspfIfNbrState' is the state of the neighbor after the\n           change.")
t11FspfMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 2, 1))
t11FspfMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 143, 2, 2))
t11FspfMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 143, 2, 1, 1)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfGeneralGroup"), ("T11-FC-FSPF-MIB", "t11FspfIfGroup"), ("T11-FC-FSPF-MIB", "t11FspfDatabaseGroup"), ("T11-FC-FSPF-MIB", "t11FspfNotificationGroup"), ("T11-FC-FSPF-MIB", "t11FspfIfCounterGroup"),))
if mibBuilder.loadTexts: t11FspfMIBCompliance.setDescription('The compliance statement for entities that\n           implement the FSPF.')
t11FspfGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 1)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfMinLsArrival"), ("T11-FC-FSPF-MIB", "t11FspfMinLsInterval"), ("T11-FC-FSPF-MIB", "t11FspfLsRefreshTime"), ("T11-FC-FSPF-MIB", "t11FspfMaxAge"), ("T11-FC-FSPF-MIB", "t11FspfMaxAgeDiscards"), ("T11-FC-FSPF-MIB", "t11FspfPathComputations"), ("T11-FC-FSPF-MIB", "t11FspfChecksumErrors"), ("T11-FC-FSPF-MIB", "t11FspfLsrs"), ("T11-FC-FSPF-MIB", "t11FspfCreateTime"), ("T11-FC-FSPF-MIB", "t11FspfAdminStatus"), ("T11-FC-FSPF-MIB", "t11FspfOperStatus"), ("T11-FC-FSPF-MIB", "t11FspfNbrStateChangNotifyEnable"), ("T11-FC-FSPF-MIB", "t11FspfSetToDefault"), ("T11-FC-FSPF-MIB", "t11FspfStorageType"),))
if mibBuilder.loadTexts: t11FspfGeneralGroup.setDescription('A collection of objects for displaying and\n           configuring FSPF parameters.')
t11FspfIfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 2)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfIfHelloInterval"), ("T11-FC-FSPF-MIB", "t11FspfIfDeadInterval"), ("T11-FC-FSPF-MIB", "t11FspfIfRetransmitInterval"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrState"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrDomainId"), ("T11-FC-FSPF-MIB", "t11FspfIfNbrPortIndex"), ("T11-FC-FSPF-MIB", "t11FspfIfAdminStatus"), ("T11-FC-FSPF-MIB", "t11FspfIfCreateTime"), ("T11-FC-FSPF-MIB", "t11FspfIfSetToDefault"), ("T11-FC-FSPF-MIB", "t11FspfIfLinkCostFactor"), ("T11-FC-FSPF-MIB", "t11FspfIfRowStatus"), ("T11-FC-FSPF-MIB", "t11FspfIfStorageType"), ("T11-FC-FSPF-MIB", "t11FspfIfPrevNbrState"),))
if mibBuilder.loadTexts: t11FspfIfGroup.setDescription('A collection of objects for displaying the FSPF\n           interface information.')
t11FspfIfCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 3)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfIfInLsuPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfInLsaPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfOutLsuPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfOutLsaPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfOutHelloPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfInHelloPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfRetransmittedLsuPkts"), ("T11-FC-FSPF-MIB", "t11FspfIfInErrorPkts"),))
if mibBuilder.loadTexts: t11FspfIfCounterGroup.setDescription('A collection of objects for counting particular\n            FSPF-packet occurrences on an interface.')
t11FspfDatabaseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 4)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfLsrAdvDomainId"), ("T11-FC-FSPF-MIB", "t11FspfLsrAge"), ("T11-FC-FSPF-MIB", "t11FspfLsrIncarnationNumber"), ("T11-FC-FSPF-MIB", "t11FspfLsrCheckSum"), ("T11-FC-FSPF-MIB", "t11FspfLsrLinks"), ("T11-FC-FSPF-MIB", "t11FspfLinkNbrDomainId"), ("T11-FC-FSPF-MIB", "t11FspfLinkPortIndex"), ("T11-FC-FSPF-MIB", "t11FspfLinkNbrPortIndex"), ("T11-FC-FSPF-MIB", "t11FspfLinkType"), ("T11-FC-FSPF-MIB", "t11FspfLinkCost"), ("T11-FC-FSPF-MIB", "t11FspfLinkNumber"),))
if mibBuilder.loadTexts: t11FspfDatabaseGroup.setDescription('A collection of objects for displaying the FSPF\n           topology database information.')
t11FspfNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 143, 2, 2, 5)).setObjects(*(("T11-FC-FSPF-MIB", "t11FspfNbrStateChangNotify"),))
if mibBuilder.loadTexts: t11FspfNotificationGroup.setDescription('A collection of notifications for FSPF.')
mibBuilder.exportSymbols("T11-FC-FSPF-MIB", T11FspfLinkType=T11FspfLinkType, t11FspfIfAdminStatus=t11FspfIfAdminStatus, t11FspfLinkIndex=t11FspfLinkIndex, t11FspfIfNbrPortIndex=t11FspfIfNbrPortIndex, t11FspfIfRowStatus=t11FspfIfRowStatus, t11FspfIfInErrorPkts=t11FspfIfInErrorPkts, t11FspfLsrIncarnationNumber=t11FspfLsrIncarnationNumber, t11FspfIfOutHelloPkts=t11FspfIfOutHelloPkts, t11FspfLinkTable=t11FspfLinkTable, t11FspfLinkEntry=t11FspfLinkEntry, t11FspfFabricIndex=t11FspfFabricIndex, T11FspfInterfaceState=T11FspfInterfaceState, t11FspfMinLsInterval=t11FspfMinLsInterval, t11FspfEntry=t11FspfEntry, t11FspfIfNbrDomainId=t11FspfIfNbrDomainId, t11FspfMIBCompliance=t11FspfMIBCompliance, t11FspfLinkType=t11FspfLinkType, t11FspfAdminStatus=t11FspfAdminStatus, t11FspfIfRetransmitInterval=t11FspfIfRetransmitInterval, t11FspfMIBCompliances=t11FspfMIBCompliances, t11FspfLsrLinks=t11FspfLsrLinks, t11FspfMinLsArrival=t11FspfMinLsArrival, t11FspfLinkNbrPortIndex=t11FspfLinkNbrPortIndex, t11FspfIfOutLsuPkts=t11FspfIfOutLsuPkts, t11FspfMaxAgeDiscards=t11FspfMaxAgeDiscards, t11FspfIfDeadInterval=t11FspfIfDeadInterval, t11FspfLsrAge=t11FspfLsrAge, t11FspfLinkCost=t11FspfLinkCost, t11FcFspfMIB=t11FcFspfMIB, t11FspfChecksumErrors=t11FspfChecksumErrors, t11FspfIfEntry=t11FspfIfEntry, t11FspfLinkNumber=t11FspfLinkNumber, t11FspfIfIndex=t11FspfIfIndex, t11FspfIfHelloInterval=t11FspfIfHelloInterval, PYSNMP_MODULE_ID=t11FcFspfMIB, t11FspfCreateTime=t11FspfCreateTime, t11FspfStorageType=t11FspfStorageType, t11FspfIfTable=t11FspfIfTable, t11FspfIfNbrState=t11FspfIfNbrState, t11FspfLsrAdvDomainId=t11FspfLsrAdvDomainId, t11FspfIfSetToDefault=t11FspfIfSetToDefault, t11FspfGeneralGroup=t11FspfGeneralGroup, t11FspfIfOutLsaPkts=t11FspfIfOutLsaPkts, t11FspfNotificationGroup=t11FspfNotificationGroup, t11FspfIfPrevNbrState=t11FspfIfPrevNbrState, t11FspfPathComputations=t11FspfPathComputations, t11FspfTable=t11FspfTable, t11FspfIfInLsuPkts=t11FspfIfInLsuPkts, t11FspfIfLinkCostFactor=t11FspfIfLinkCostFactor, t11FspfIfGroup=t11FspfIfGroup, t11FspfLsrDomainId=t11FspfLsrDomainId, t11FspfLsrType=t11FspfLsrType, t11FspfNbrStateChangNotify=t11FspfNbrStateChangNotify, t11FspfLinkNbrDomainId=t11FspfLinkNbrDomainId, t11FspfLinkPortIndex=t11FspfLinkPortIndex, T11FspfLastCreationTime=T11FspfLastCreationTime, t11FspfObjects=t11FspfObjects, t11FspfNotifications=t11FspfNotifications, t11FspfMaxAge=t11FspfMaxAge, t11FspfIfRetransmittedLsuPkts=t11FspfIfRetransmittedLsuPkts, t11FspfLsrEntry=t11FspfLsrEntry, t11FspfNbrStateChangNotifyEnable=t11FspfNbrStateChangNotifyEnable, t11FspfLsrTable=t11FspfLsrTable, t11FspfLsrs=t11FspfLsrs, t11FspfLsrCheckSum=t11FspfLsrCheckSum, t11FspfDatabaseGroup=t11FspfDatabaseGroup, t11FspfIfStorageType=t11FspfIfStorageType, t11FspfSetToDefault=t11FspfSetToDefault, t11FspfIfInHelloPkts=t11FspfIfInHelloPkts, t11FspfIfInLsaPkts=t11FspfIfInLsaPkts, t11FspfIfCreateTime=t11FspfIfCreateTime, T11FspfLsrType=T11FspfLsrType, t11FspfConformance=t11FspfConformance, t11FspfMIBGroups=t11FspfMIBGroups, t11FspfIfCounterGroup=t11FspfIfCounterGroup, t11FspfDatabase=t11FspfDatabase, t11FspfConfiguration=t11FspfConfiguration, t11FspfOperStatus=t11FspfOperStatus, t11FspfLsRefreshTime=t11FspfLsRefreshTime)
